@@ -12,10 +12,10 @@ from PySimpleGUI import POPUP_BUTTONS_OK_CANCEL, PySimpleGUI
 from markdown2 import markdown
 from satcfdi import DatePeriod, CFDI, Code, Signer
 from satcfdi.accounting import filter_invoices_iter, SatCFDI
-from satcfdi.create.cfd import cfdi40
 from satcfdi.exceptions import ResponseError, DocumentNotFoundError
 from satcfdi.pacs import Accept
 from satcfdi.pacs.sat import SAT, TipoDescargaMasivaTerceros, EstadoSolicitud
+from satcfdi.printer import Representable
 # noinspection PyUnresolvedReferences
 from satcfdi.transform.catalog import CATALOGS
 from weasyprint import HTML, CSS
@@ -24,12 +24,12 @@ from . import SOURCE_DIRECTORY, __version__
 from .client_validation import validar_client
 from .file_data_managers import environment_default, environment_bold_escaped, ClientsManager, ConfigManager, FacturasManager
 from .formatting_functions.common import fecha, pesos, porcentaje
-from .gui_functions import generate_ingresos, pago_factura, find_ajustes, format_concepto_desc, exportar_facturas, exportar_facturas_filename, parse_ym_date
+from .gui_functions import generate_ingresos, pago_factura, find_ajustes, format_concepto_desc, exportar_facturas, exportar_facturas_filename, parse_ym_date, parse_date_period
 from .layout import make_layout, InvoiceButtonManager, EmailButtonManager
 from .local import LocalDBSatCFDI
 from .log_tools import log_line, log_item, cfdi_header, print_yaml, header_line
 from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder, PPD, PUE
-from .utils import random_string, to_uuid, add_file_handler, convert_ans1_date
+from .utils import random_string, to_uuid, add_file_handler
 
 logging.getLogger("weasyprint").setLevel(logging.ERROR)
 logging.getLogger("fontTools").setLevel(logging.ERROR)
@@ -67,44 +67,28 @@ class FacturacionGUI:
         self.all_invoices = None
         self.config = None
         self.local_db = None
-        self.base_template = None
-        self.issuer_cif = None
 
         self.invoice_button_manager = InvoiceButtonManager(self.window["crear_facturas"], self.window["detallado"])
         self.email_button_manager = EmailButtonManager(self.window["enviar_correos"])
         self.console = self.window["console"]
 
     def prepare(self):
-        clients = ClientsManager()
         self.config = ConfigManager()
         self.local_db = LocalDBSatCFDI(self.config)
 
-        issuer_cif = clients[self.csd_signer.rfc]
-        self.issuer_cif = issuer_cif
-
-        self.base_template = {
-            "Emisor": cfdi40.Emisor(
-                rfc=issuer_cif['Rfc'],
-                nombre=issuer_cif['RazonSocial'],
-                regimen_fiscal=issuer_cif['RegimenFiscal']
-            ),
-            "LugarExpedicion": issuer_cif['CodigoPostal']
-        }
-
         MyCFDI.issuer_rfc = self.csd_signer.rfc
         MyCFDI.local_db = self.local_db
 
         # update window title
         self.window.set_title(
-            f"Facturacion 4.0  RFC: {self.csd_signer.rfc}  RazonSocial: {issuer_cif['RazonSocial']}  RegimenFiscal: {issuer_cif['RegimenFiscal']}  "
-            f"LugarExpedicion: {issuer_cif['CodigoPostal']}"
+            f"Facturación Masiva CFDI 4.0  RFC: {self.csd_signer.rfc}"
         )
 
-    def initial_screen(self):
+    def initial_screen(self, emisor_cif):
         print_yaml({
             "version": __version__.__version__,
             "facturacion": "CFDI 4.0",
-            "emisor": self.base_template,
+            "emisor": emisor_cif,
             "pac_service": {
                 "Type": type(self.pac_service).__name__,
                 "Rfc": self.pac_service.RFC,
@@ -122,7 +106,9 @@ class FacturacionGUI:
 
         try:
             self.prepare()
-            self.initial_screen()
+            clients = ClientsManager()
+            emisor_cif = clients[self.csd_signer.rfc]
+            self.initial_screen(emisor_cif)
         except Exception:
             logger.exception(header_line("ERROR"))
             for e in self.window.element_list():
@@ -150,7 +136,7 @@ class FacturacionGUI:
         for i in range(attempts):
             if i:
                 print(f'Intentando de nuevo... Intento {i + 1} de {attempts}')
-                self._read(timeout=1000 * i)
+                self._read(timeout=2000 * i)
 
             try:
                 res = self.pac_service.stamp(
@@ -159,7 +145,7 @@ class FacturacionGUI:
                     ref_id=ref_id
                 )
             except Exception as ex:
-                logger.error(f'Error Generando: {cfdi_header(MyCFDI(invoice))}')
+                logger.error(f"Error Generando: {invoice.get('Serie')}{invoice.get('Folio')} {invoice['Receptor']['Rfc']}")
                 if isinstance(ex, ResponseError):
                     logger.error(f"Status Code: {ex.response.status_code}")
                     logger.error(f"Response: {ex.response.text}")
@@ -168,7 +154,7 @@ class FacturacionGUI:
             self.config.inc_folio()
             return move_to_folder(res.xml, pdf_data=res.pdf)
 
-    def enviar_correos(self, emails):
+    def enviar_correos(self, emisor_cif, emails):
         with self.email_manager.sender as s:
             for receptor, notify_invoices, pendientes_meses_anteriores in emails:
                 attachments = []
@@ -184,7 +170,8 @@ class FacturacionGUI:
                         fields={
                             "facturas": notify_invoices,
                             'pendientes_meses_anteriores': pendientes_meses_anteriores,
-                        }
+                            'emisor': emisor_cif,
+                        },
                     ),
                     file_attachments=attachments
                 )
@@ -229,7 +216,6 @@ class FacturacionGUI:
     def generate_pdf_template(self, template_name, fields):
         increment_template = environment_bold_escaped.get_template(template_name)
         md5_document = increment_template.render(
-            emisor=self.issuer_cif,
             fecha_hoy=fecha(date.today()),
             **fields
         )
@@ -248,7 +234,7 @@ class FacturacionGUI:
     def generate_html_template(self, template_name, fields):
         increment_template = environment_default.get_template(template_name)
         render = increment_template.render(
-            emisor=self.issuer_cif, **fields
+            fields
         )
         return render
 
@@ -342,7 +328,8 @@ class FacturacionGUI:
 
                 match event:
                     case "about":
-                        self.initial_screen()
+                        clients = ClientsManager()
+                        self.initial_screen(clients[self.csd_signer.rfc])
 
                     case "factura_pagar" | "buscar_factura":
                         text = self.window["factura_pagar"].get().strip()
@@ -465,6 +452,7 @@ class FacturacionGUI:
                                         self.unzip_cfdi(b)
                                 del self.config[event]
                                 self.config.save()
+                            log_line("FIN")
 
                     case "validate_clientes":
                         log_line("VALIDAR CLIENTES")
@@ -490,8 +478,7 @@ class FacturacionGUI:
                             clients=ClientsManager(),
                             facturas=FacturasManager()["Facturas"],
                             values=values,
-                            csd_signer=self.csd_signer,
-                            base_template=self.base_template
+                            csd_signer=self.csd_signer
                         )
                         if facturas:
                             for i, cfdi in enumerate(facturas, start=1):
@@ -510,8 +497,7 @@ class FacturacionGUI:
                                 factura_pagar=i,
                                 fecha_pago=values["fecha_pago"],
                                 forma_pago=values["forma_pago"],
-                                csd_signer=self.csd_signer,
-                                lugar_expedicion=self.base_template["LugarExpedicion"]
+                                csd_signer=self.csd_signer
                             )
                             if cfdi_pago:
                                 self.log_cfdi(cfdi_pago)
@@ -647,7 +633,9 @@ class FacturacionGUI:
                             button_type=POPUP_BUTTONS_OK_CANCEL
                         )
                         if res == "OK":
-                            self.enviar_correos(emails_to_send)
+                            clients = ClientsManager()
+                            emisor_cif = clients[self.csd_signer.rfc]
+                            self.enviar_correos(emisor_cif, emails_to_send)
                             log_item("FIN")
                         else:
                             log_item("OPERACION CANCELADA")
@@ -695,14 +683,38 @@ class FacturacionGUI:
 
                     case "exportar_facturas":
                         log_line("EXPORTAR FACTURAS")
-                        exportar_facturas(self.get_all_invoices(), values["periodo"], self.csd_signer.rfc, self.issuer_cif['RegimenFiscal'])
+                        clients = ClientsManager()
+                        emisor_cif = clients[self.csd_signer.rfc]
+                        exportar_facturas(
+                            self.get_all_invoices(),
+                            parse_date_period(values["periodo"]),
+                            emisor_cif,
+                            self.config['rfc_prediales']
+                        )
 
                     case "ver_excel":
-                        archivo_excel = exportar_facturas_filename(values["periodo"])
+                        archivo_excel = exportar_facturas_filename(parse_date_period(values["periodo"]))
                         os.startfile(
                             os.path.abspath(archivo_excel)
                         )
 
+                    case "ver_html":
+                        inv = self.get_all_invoices().values()
+                        dp = parse_date_period(values["periodo"])
+                        inv = filter_invoices_iter(
+                            invoices=inv,
+                            fecha=dp,
+                            rfc_emisor=self.csd_signer.rfc,
+                        )
+                        outfile = exportar_facturas_filename(dp, ext="html")
+                        Representable.html_write_all(
+                            objs=inv,
+                            target=outfile,
+                        )
+                        os.startfile(
+                            os.path.abspath(outfile)
+                        )
+
                     case "periodo" | "inicio" | "final" | "fecha_pago" | "forma_pago":
                         pass
 
