@@ -10,17 +10,21 @@ def print_yaml(data):
 
 def log_email(receptor, notify_invoices, facturas_pendientes):
     print_yaml({
-        "Rfc": Code(receptor["Rfc"], receptor["RazonSocial"]),
-        "Facturas": [f"{i.name} - {i.uuid}" for i in notify_invoices],
-        "PendientesMesesAnteriores": [f"{i.name} - {i.uuid}" for i in facturas_pendientes],
-        "Correos": receptor["Email"]
+        "rfc": Code(receptor["Rfc"], receptor["RazonSocial"]),
+        "facturas": [f"{i.name} - {i.uuid}" for i in notify_invoices],
+        "pendientes_meses_anteriores": [f"{i.name} - {i.uuid}" for i in facturas_pendientes],
+        "correos": receptor["Email"]
     })
 
 
-def log_line(text):
+def header_line(text):
     ln = (150 - len(text)) // 2
+    return ("=" * ln) + " " + text + " " + ("=" * ln)
+
+
+def log_line(text):
     print(
-        ("=" * ln) + " " + text + " " + ("=" * ln),
+        header_line(text)
     )
 
 
